@@ -20,7 +20,7 @@ typedef Eo Efl_Ui_Layout_Part_Legacy;
  */
 #define EFL_UI_LAYOUT_PART_LEGACY_CLASS efl_ui_layout_part_legacy_class_get()
 
-EWAPI const Efl_Class *efl_ui_layout_part_legacy_class_get(void);
+EWAPI const Efl_Class *efl_ui_layout_part_legacy_class_get(void) EINA_CONST;
 #endif /* EFL_BETA_API_SUPPORT */
 
 #endif
