@@ -26,7 +26,7 @@ typedef Eo Efl_Ui_Spin_Button;
  */
 #define EFL_UI_SPIN_BUTTON_CLASS efl_ui_spin_button_class_get()
 
-EWAPI const Efl_Class *efl_ui_spin_button_class_get(void);
+EWAPI const Efl_Class *efl_ui_spin_button_class_get(void) EINA_CONST;
 
 /**
  * @brief Control whether the spin should circulate value when it reaches its
